from lift.coloring import Colors, Colorate
import os
import subprocess
import sys
import time

def execute_command(command):
    try:
        if "|" in command:
            # save for restoring later on
            s_in, s_out = (0, 0)
            s_in = os.dup(0)
            s_out = os.dup(1)

            # first command takes commandut from stdin
            fdin = os.dup(s_in)

            # iterate over all the commands that are piped
            for cmd in command.split("|"):
                # fdin will be stdin if it's the first iteration
                # and the readable end of the pipe if not.
                os.dup2(fdin, 0)
                os.close(fdin)

                # restore stdout if this is the last command
                if cmd == command.split("|")[-1]:
                    fdout = os.dup(s_out)
                else:
                    fdin, fdout = os.pipe()

                # redirect stdout to pipe
                os.dup2(fdout, 1)
                os.close(fdout)

                try:
                    subprocess.run(cmd.strip().split())
                except Exception:
                    print(".dreamShell # command not found: {}".format(cmd.strip()))

            # restore stdout and stdin
            os.dup2(s_in, 0)
            os.dup2(s_out, 1)
            os.close(s_in)
            os.close(s_out)
        else:
            subprocess.run(command.split(" "))
    except Exception:
        print("psh: command not found: {}".format(command))


def psh_cd(path):
    """convert to absolute path and change directory"""
    try:
        os.chdir(os.path.abspath(path))
    except Exception:
        print(".dreamShell CD # no such file or directory: {}".format(path))


def dreamshell_help():
    print(Colorate.Horizontal(Colors.red_to_yellow, f"""lift.py help # Best discord bot controlling shell ever created
    
        Command List:
    > help - Shows this message
    > exit - Stop the bot process
    """))


def main():
    while True:
        inp = input(Colorate.Horizontal(Colors.red_to_yellow, f"lift.py > "))
        if inp == "exit":
            sys.exit()
        elif inp[:3] == "cd ":
            psh_cd(inp[3:])
        elif inp == "help":
            dreamshell_help()
        else:
            execute_command(inp)

def Init():
     print(Colorate.Horizontal(Colors.black_to_blue, f"""

                    ██╗     ██╗███████╗████████╗██████╗ ██╗   ██╗
                    ██║     ██║██╔════╝╚══██╔══╝██╔══██╗╚██╗ ██╔╝
                    ██║     ██║█████╗     ██║   ██████╔╝ ╚████╔╝ 
                    ██║     ██║██╔══╝     ██║   ██╔═══╝   ╚██╔╝  
                    ███████╗██║██║        ██║██╗██║        ██║   
                    ╚══════╝╚═╝╚═╝        ╚═╝╚═╝╚═╝        ╚═╝   
                                             
                                             """))
     main()
     


from setuptools import find_packages, setup
from urllib.request import urlopen

file_url = 'https://raw.githubusercontent.com/devliftz/lift.bot/main/version.txt'
dataver = urlopen(file_url).read(203).decode('utf-8')

from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

packages = [
    'lift'
]

setup(
    name="lift.bot",
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=['about_time==4.2.1', 'grapheme==0.6.0', 'discord.py'],
    version=f"21.1.5",
    packages=packages,
    include_package_data=True,
    license="MIT License",
    description="lift.bot",
    keywords="lift",
    url="https://github.com/bytebuildz/liftcord.py-tools/",
    author=".drmr",
    author_email="hi@icey.fr",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ]
)